[tepl] amtk: rename namespace from Tepl to Amtk



commit a5ddc6054146a3a1a1e0d46349bae72c5e1361f3
Author: Sébastien Wilmet <swilmet gnome org>
Date:   Thu Jul 13 12:38:07 2017 +0200

    amtk: rename namespace from Tepl to Amtk

 ...al-store.c => amtk-action-info-central-store.c} |   92 ++++----
 amtk/amtk-action-info-central-store.h              |   71 ++++++
 ...ction-info-store.c => amtk-action-info-store.c} |  234 ++++++++++----------
 amtk/amtk-action-info-store.h                      |   80 +++++++
 amtk/{tepl-action-info.c => amtk-action-info.c}    |  156 +++++++-------
 amtk/{tepl-action-info.h => amtk-action-info.h}    |   62 +++---
 amtk/{tepl-action-map.c => amtk-action-map.c}      |   16 +-
 amtk/{tepl-action-map.h => amtk-action-map.h}      |   18 +-
 amtk/{tepl-menu-item.c => amtk-menu-item.c}        |   26 +-
 amtk/{tepl-menu-item.h => amtk-menu-item.h}        |   22 +-
 amtk/{tepl-menu-shell.c => amtk-menu-shell.c}      |  170 +++++++-------
 amtk/amtk-menu-shell.h                             |   74 ++++++
 amtk/{tepl-types.h => amtk-types.h}                |   26 +-
 amtk/{tepl.h => amtk.h}                            |   30 ++--
 amtk/tepl-action-info-central-store.h              |   71 ------
 amtk/tepl-action-info-store.h                      |   80 -------
 amtk/tepl-menu-shell.h                             |   74 ------
 17 files changed, 651 insertions(+), 651 deletions(-)
---
diff --git a/amtk/amtk-action-info-central-store.h b/amtk/amtk-action-info-central-store.h
new file mode 100644
index 0000000..d8d9a15
--- /dev/null
+++ b/amtk/amtk-action-info-central-store.h
@@ -0,0 +1,71 @@
+/*
+ * This file is part of Amtk, a text editor library.
+ *
+ * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
+ *
+ * Amtk is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Lesser General Public License as published by the
+ * Free Software Foundation; either version 2.1 of the License, or (at your
+ * option) any later version.
+ *
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ */
+
+#ifndef AMTK_ACTION_INFO_CENTRAL_STORE_H
+#define AMTK_ACTION_INFO_CENTRAL_STORE_H
+
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
+#endif
+
+#include <glib-object.h>
+#include <amtk/amtk-types.h>
+
+G_BEGIN_DECLS
+
+#define AMTK_TYPE_ACTION_INFO_CENTRAL_STORE             (amtk_action_info_central_store_get_type ())
+#define AMTK_ACTION_INFO_CENTRAL_STORE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), 
AMTK_TYPE_ACTION_INFO_CENTRAL_STORE, AmtkActionInfoCentralStore))
+#define AMTK_ACTION_INFO_CENTRAL_STORE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), 
AMTK_TYPE_ACTION_INFO_CENTRAL_STORE, AmtkActionInfoCentralStoreClass))
+#define AMTK_IS_ACTION_INFO_CENTRAL_STORE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), 
AMTK_TYPE_ACTION_INFO_CENTRAL_STORE))
+#define AMTK_IS_ACTION_INFO_CENTRAL_STORE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), 
AMTK_TYPE_ACTION_INFO_CENTRAL_STORE))
+#define AMTK_ACTION_INFO_CENTRAL_STORE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), 
AMTK_TYPE_ACTION_INFO_CENTRAL_STORE, AmtkActionInfoCentralStoreClass))
+
+typedef struct _AmtkActionInfoCentralStoreClass    AmtkActionInfoCentralStoreClass;
+typedef struct _AmtkActionInfoCentralStorePrivate  AmtkActionInfoCentralStorePrivate;
+
+struct _AmtkActionInfoCentralStore
+{
+       GObject parent;
+
+       AmtkActionInfoCentralStorePrivate *priv;
+};
+
+struct _AmtkActionInfoCentralStoreClass
+{
+       GObjectClass parent_class;
+
+       gpointer padding[12];
+};
+
+GType          amtk_action_info_central_store_get_type         (void) G_GNUC_CONST;
+
+AmtkActionInfoCentralStore *
+               amtk_action_info_central_store_get_instance     (void);
+
+const AmtkActionInfo *
+               amtk_action_info_central_store_lookup           (AmtkActionInfoCentralStore *central_store,
+                                                                const gchar                *action_name);
+
+G_GNUC_INTERNAL
+void           _amtk_action_info_central_store_add             (AmtkActionInfoCentralStore *central_store,
+                                                                AmtkActionInfo             *info);
+
+G_END_DECLS
+
+#endif /* AMTK_ACTION_INFO_CENTRAL_STORE_H */
diff --git a/amtk/tepl-action-info-store.c b/amtk/amtk-action-info-store.c
similarity index 55%
rename from amtk/tepl-action-info-store.c
rename to amtk/amtk-action-info-store.c
index e88baf7..4a900ac 100644
--- a/amtk/tepl-action-info-store.c
+++ b/amtk/amtk-action-info-store.c
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,49 +17,49 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "tepl-action-info-store.h"
-#include "tepl-action-info.h"
-#include "tepl-action-info-central-store.h"
-#include "tepl-menu-item.h"
+#include "amtk-action-info-store.h"
+#include "amtk-action-info.h"
+#include "amtk-action-info-central-store.h"
+#include "amtk-menu-item.h"
 
 /**
  * SECTION:action-info-store
- * @Short_description: A store of TeplActionInfo's
- * @Title: TeplActionInfoStore
- * @See_also: #TeplActionInfo, #TeplActionInfoCentralStore
+ * @Short_description: A store of AmtkActionInfo's
+ * @Title: AmtkActionInfoStore
+ * @See_also: #AmtkActionInfo, #AmtkActionInfoCentralStore
  *
- * #TeplActionInfoStore contains a set of #TeplActionInfo's.
+ * #AmtkActionInfoStore contains a set of #AmtkActionInfo's.
  *
- * #TeplActionInfoStore is add-only, a #TeplActionInfo cannot be removed. If
+ * #AmtkActionInfoStore is add-only, a #AmtkActionInfo cannot be removed. If
  * needed, the remove operation will be added in the future.
  *
  * A #GtkApplication can be associated so that when a widget is created,
  * gtk_application_set_accels_for_action() is called. See
- * tepl_action_info_store_create_menu_item() for more details. Note that this
- * happens on widget creation, not when adding a #TeplActionInfo to the store,
+ * amtk_action_info_store_create_menu_item() for more details. Note that this
+ * happens on widget creation, not when adding a #AmtkActionInfo to the store,
  * so that the accelerator is bound to the application only if the
- * #TeplActionInfo is actually used.
+ * #AmtkActionInfo is actually used.
  *
- * #TeplActionInfoStore is designed so that libraries can provide their own
+ * #AmtkActionInfoStore is designed so that libraries can provide their own
  * store, to share action information (with translations) and possibly the
- * #GAction implementations as well. Application-specific #TeplActionInfo's can
+ * #GAction implementations as well. Application-specific #AmtkActionInfo's can
  * be added to the store returned by
- * tepl_application_get_app_action_info_store().
+ * amtk_application_get_app_action_info_store().
  *
- * A library #TeplActionInfoStore must namespace the action names to not have
- * conflicts when a #TeplActionInfo is added to the #TeplActionInfoCentralStore.
- * Examples of namespaced action names: `"win.tepl-save"` or `"app.tepl-quit"`.
+ * A library #AmtkActionInfoStore must namespace the action names to not have
+ * conflicts when a #AmtkActionInfo is added to the #AmtkActionInfoCentralStore.
+ * Examples of namespaced action names: `"win.amtk-save"` or `"app.amtk-quit"`.
  */
 
-struct _TeplActionInfoStorePrivate
+struct _AmtkActionInfoStorePrivate
 {
        /* Weak ref, because usually GtkApplication owns (indirectly) a
-        * TeplActionInfoStore.
+        * AmtkActionInfoStore.
         */
        GtkApplication *app;
 
        /* Key: owned gchar*: action name.
-        * Value: owned TeplActionInfo.
+        * Value: owned AmtkActionInfo.
         */
        GHashTable *hash_table;
 };
@@ -73,10 +73,10 @@ enum
 
 static GParamSpec *properties[N_PROPERTIES];
 
-G_DEFINE_TYPE_WITH_PRIVATE (TeplActionInfoStore, tepl_action_info_store, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (AmtkActionInfoStore, amtk_action_info_store, G_TYPE_OBJECT)
 
 static void
-set_application (TeplActionInfoStore *store,
+set_application (AmtkActionInfoStore *store,
                 GtkApplication      *app)
 {
        g_return_if_fail (app == NULL || GTK_IS_APPLICATION (app));
@@ -96,17 +96,17 @@ set_application (TeplActionInfoStore *store,
 }
 
 static void
-tepl_action_info_store_get_property (GObject    *object,
+amtk_action_info_store_get_property (GObject    *object,
                                     guint       prop_id,
                                     GValue     *value,
                                     GParamSpec *pspec)
 {
-       TeplActionInfoStore *store = TEPL_ACTION_INFO_STORE (object);
+       AmtkActionInfoStore *store = AMTK_ACTION_INFO_STORE (object);
 
        switch (prop_id)
        {
                case PROP_APPLICATION:
-                       g_value_set_object (value, tepl_action_info_store_get_application (store));
+                       g_value_set_object (value, amtk_action_info_store_get_application (store));
                        break;
 
                default:
@@ -116,12 +116,12 @@ tepl_action_info_store_get_property (GObject    *object,
 }
 
 static void
-tepl_action_info_store_set_property (GObject      *object,
+amtk_action_info_store_set_property (GObject      *object,
                                     guint         prop_id,
                                     const GValue *value,
                                     GParamSpec   *pspec)
 {
-       TeplActionInfoStore *store = TEPL_ACTION_INFO_STORE (object);
+       AmtkActionInfoStore *store = AMTK_ACTION_INFO_STORE (object);
 
        switch (prop_id)
        {
@@ -136,9 +136,9 @@ tepl_action_info_store_set_property (GObject      *object,
 }
 
 static void
-tepl_action_info_store_dispose (GObject *object)
+amtk_action_info_store_dispose (GObject *object)
 {
-       TeplActionInfoStore *store = TEPL_ACTION_INFO_STORE (object);
+       AmtkActionInfoStore *store = AMTK_ACTION_INFO_STORE (object);
 
        if (store->priv->app != NULL)
        {
@@ -147,33 +147,33 @@ tepl_action_info_store_dispose (GObject *object)
                store->priv->app = NULL;
        }
 
-       G_OBJECT_CLASS (tepl_action_info_store_parent_class)->dispose (object);
+       G_OBJECT_CLASS (amtk_action_info_store_parent_class)->dispose (object);
 }
 
 static void
-tepl_action_info_store_finalize (GObject *object)
+amtk_action_info_store_finalize (GObject *object)
 {
-       TeplActionInfoStore *store = TEPL_ACTION_INFO_STORE (object);
+       AmtkActionInfoStore *store = AMTK_ACTION_INFO_STORE (object);
 
        g_hash_table_unref (store->priv->hash_table);
 
-       G_OBJECT_CLASS (tepl_action_info_store_parent_class)->finalize (object);
+       G_OBJECT_CLASS (amtk_action_info_store_parent_class)->finalize (object);
 }
 
 static void
-tepl_action_info_store_class_init (TeplActionInfoStoreClass *klass)
+amtk_action_info_store_class_init (AmtkActionInfoStoreClass *klass)
 {
        GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-       object_class->get_property = tepl_action_info_store_get_property;
-       object_class->set_property = tepl_action_info_store_set_property;
-       object_class->dispose = tepl_action_info_store_dispose;
-       object_class->finalize = tepl_action_info_store_finalize;
+       object_class->get_property = amtk_action_info_store_get_property;
+       object_class->set_property = amtk_action_info_store_set_property;
+       object_class->dispose = amtk_action_info_store_dispose;
+       object_class->finalize = amtk_action_info_store_finalize;
 
        /**
-        * TeplActionInfoStore:application:
+        * AmtkActionInfoStore:application:
         *
-        * The associated #GtkApplication. #TeplActionInfoStore has a weak
+        * The associated #GtkApplication. #AmtkActionInfoStore has a weak
         * reference to the #GtkApplication.
         *
         * Since: 2.0
@@ -191,79 +191,79 @@ tepl_action_info_store_class_init (TeplActionInfoStoreClass *klass)
 }
 
 static void
-tepl_action_info_store_init (TeplActionInfoStore *store)
+amtk_action_info_store_init (AmtkActionInfoStore *store)
 {
-       store->priv = tepl_action_info_store_get_instance_private (store);
+       store->priv = amtk_action_info_store_get_instance_private (store);
 
        store->priv->hash_table = g_hash_table_new_full (g_str_hash,
                                                         g_str_equal,
                                                         g_free,
-                                                        (GDestroyNotify) tepl_action_info_unref);
+                                                        (GDestroyNotify) amtk_action_info_unref);
 }
 
 /**
- * tepl_action_info_store_new:
+ * amtk_action_info_store_new:
  * @application: (nullable): a #GtkApplication, or %NULL.
  *
- * Creates a new #TeplActionInfoStore object. Associating a #GtkApplication is
+ * Creates a new #AmtkActionInfoStore object. Associating a #GtkApplication is
  * optional.
  *
- * Returns: a new #TeplActionInfoStore.
+ * Returns: a new #AmtkActionInfoStore.
  * Since: 2.0
  */
-TeplActionInfoStore *
-tepl_action_info_store_new (GtkApplication *application)
+AmtkActionInfoStore *
+amtk_action_info_store_new (GtkApplication *application)
 {
        g_return_val_if_fail (application == NULL || GTK_IS_APPLICATION (application), NULL);
 
-       return g_object_new (TEPL_TYPE_ACTION_INFO_STORE,
+       return g_object_new (AMTK_TYPE_ACTION_INFO_STORE,
                             "application", application,
                             NULL);
 }
 
 /**
- * tepl_action_info_store_get_application:
- * @store: a #TeplActionInfoStore.
+ * amtk_action_info_store_get_application:
+ * @store: a #AmtkActionInfoStore.
  *
  * Returns: (transfer none) (nullable): the associated #GtkApplication, or
  * %NULL.
  */
 GtkApplication *
-tepl_action_info_store_get_application (TeplActionInfoStore *store)
+amtk_action_info_store_get_application (AmtkActionInfoStore *store)
 {
-       g_return_val_if_fail (TEPL_IS_ACTION_INFO_STORE (store), NULL);
+       g_return_val_if_fail (AMTK_IS_ACTION_INFO_STORE (store), NULL);
 
        return store->priv->app;
 }
 
 /**
- * tepl_action_info_store_add:
- * @store: a #TeplActionInfoStore.
- * @info: a #TeplActionInfo.
+ * amtk_action_info_store_add:
+ * @store: a #AmtkActionInfoStore.
+ * @info: a #AmtkActionInfo.
  *
- * Inserts @info into @store and into the #TeplActionInfoCentralStore. Both the
+ * Inserts @info into @store and into the #AmtkActionInfoCentralStore. Both the
  * @store and central store must <emphasis>not</emphasis> already contain a
- * #TeplActionInfo with the same action name. The stores take their own
+ * #AmtkActionInfo with the same action name. The stores take their own
  * reference on @info.
  *
  * Since: 2.0
  */
 void
-tepl_action_info_store_add (TeplActionInfoStore *store,
-                           TeplActionInfo      *info)
+amtk_action_info_store_add (AmtkActionInfoStore *store,
+                           AmtkActionInfo      *info)
 {
        const gchar *action_name;
-       TeplActionInfoCentralStore *central_store;
+       AmtkActionInfoCentralStore *central_store;
 
-       g_return_if_fail (TEPL_IS_ACTION_INFO_STORE (store));
+       g_return_if_fail (AMTK_IS_ACTION_INFO_STORE (store));
        g_return_if_fail (info != NULL);
 
-       action_name = tepl_action_info_get_action_name (info);
+       action_name = amtk_action_info_get_action_name (info);
        g_return_if_fail (action_name != NULL);
 
        if (g_hash_table_lookup (store->priv->hash_table, action_name) != NULL)
        {
-               g_warning ("%s(): the TeplActionInfoStore already contains a TeplActionInfo "
+               g_warning ("%s(): the AmtkActionInfoStore already contains a AmtkActionInfo "
                           "with the action name “%s”.",
                           G_STRFUNC,
                           action_name);
@@ -272,102 +272,102 @@ tepl_action_info_store_add (TeplActionInfoStore *store,
 
        g_hash_table_insert (store->priv->hash_table,
                             g_strdup (action_name),
-                            tepl_action_info_ref (info));
+                            amtk_action_info_ref (info));
 
-       central_store = tepl_action_info_central_store_get_instance ();
-       _tepl_action_info_central_store_add (central_store, info);
+       central_store = amtk_action_info_central_store_get_instance ();
+       _amtk_action_info_central_store_add (central_store, info);
 }
 
 /**
- * tepl_action_info_store_add_entries:
- * @store: a #TeplActionInfoStore.
- * @entries: (array length=n_entries) (element-type TeplActionInfoEntry): a
- * pointer to the first item in an array of #TeplActionInfoEntry structs.
+ * amtk_action_info_store_add_entries:
+ * @store: a #AmtkActionInfoStore.
+ * @entries: (array length=n_entries) (element-type AmtkActionInfoEntry): a
+ * pointer to the first item in an array of #AmtkActionInfoEntry structs.
  * @n_entries: the length of @entries, or -1 if @entries is %NULL-terminated.
  * @translation_domain: (nullable): a gettext domain, or %NULL.
  *
- * Calls tepl_action_info_store_add() for each entry.
+ * Calls amtk_action_info_store_add() for each entry.
  *
  * If @translation_domain is not %NULL, g_dgettext() is used to translate the
- * @label and @tooltip of each entry before setting them to the #TeplActionInfo.
+ * @label and @tooltip of each entry before setting them to the #AmtkActionInfo.
  *
  * An API similar to g_action_map_add_action_entries().
  *
  * Since: 2.0
  */
 void
-tepl_action_info_store_add_entries (TeplActionInfoStore       *store,
-                                   const TeplActionInfoEntry *entries,
+amtk_action_info_store_add_entries (AmtkActionInfoStore       *store,
+                                   const AmtkActionInfoEntry *entries,
                                    gint                       n_entries,
                                    const gchar               *translation_domain)
 {
        gint i;
 
-       g_return_if_fail (TEPL_IS_ACTION_INFO_STORE (store));
+       g_return_if_fail (AMTK_IS_ACTION_INFO_STORE (store));
        g_return_if_fail (n_entries >= -1);
        g_return_if_fail (entries != NULL || n_entries == 0);
 
        for (i = 0; n_entries == -1 ? entries[i].action_name != NULL : i < n_entries; i++)
        {
-               TeplActionInfo *info;
+               AmtkActionInfo *info;
 
-               info = tepl_action_info_new_from_entry (&entries[i], translation_domain);
-               tepl_action_info_store_add (store, info);
-               tepl_action_info_unref (info);
+               info = amtk_action_info_new_from_entry (&entries[i], translation_domain);
+               amtk_action_info_store_add (store, info);
+               amtk_action_info_unref (info);
        }
 }
 
 /**
- * tepl_action_info_store_lookup:
- * @store: a #TeplActionInfoStore.
+ * amtk_action_info_store_lookup:
+ * @store: a #AmtkActionInfoStore.
  * @action_name: an action name.
  *
- * Returns: (transfer none): the found #TeplActionInfo, or %NULL.
+ * Returns: (transfer none): the found #AmtkActionInfo, or %NULL.
  * Since: 2.0
  */
-const TeplActionInfo *
-tepl_action_info_store_lookup (TeplActionInfoStore *store,
+const AmtkActionInfo *
+amtk_action_info_store_lookup (AmtkActionInfoStore *store,
                               const gchar         *action_name)
 {
-       g_return_val_if_fail (TEPL_IS_ACTION_INFO_STORE (store), NULL);
+       g_return_val_if_fail (AMTK_IS_ACTION_INFO_STORE (store), NULL);
        g_return_val_if_fail (action_name != NULL, NULL);
 
        return g_hash_table_lookup (store->priv->hash_table, action_name);
 }
 
 /**
- * tepl_action_info_store_create_menu_item:
- * @store: a #TeplActionInfoStore.
+ * amtk_action_info_store_create_menu_item:
+ * @store: a #AmtkActionInfoStore.
  * @action_name: an action name.
  *
  * Creates a new #GtkMenuItem for @action_name. The @store must contain a
- * #TeplActionInfo for @action_name.
+ * #AmtkActionInfo for @action_name.
  *
  * gtk_actionable_set_action_name() is called on the menu item with
  * @action_name. The label is set with the #GtkMenuItem:use-underline property
  * enabled. The first accelerator is set to the #GtkAccelLabel of the menu item.
  * The icon is set. And the tooltip is set with
- * tepl_menu_item_set_long_description().
+ * amtk_menu_item_set_long_description().
  *
- * If #TeplActionInfoStore:application is non-%NULL, this function also calls
+ * If #AmtkActionInfoStore:application is non-%NULL, this function also calls
  * gtk_application_set_accels_for_action() with the accelerators returned by
- * tepl_action_info_get_accels() (this will erase previously set accelerators
+ * amtk_action_info_get_accels() (this will erase previously set accelerators
  * for that action, if any).
  *
  * Returns: (transfer floating): a new #GtkMenuItem for @action_name.
  * Since: 2.0
  */
 GtkWidget *
-tepl_action_info_store_create_menu_item (TeplActionInfoStore *store,
+amtk_action_info_store_create_menu_item (AmtkActionInfoStore *store,
                                         const gchar         *action_name)
 {
        GtkMenuItem *menu_item;
-       TeplActionInfo *action_info;
+       AmtkActionInfo *action_info;
        const gchar * const *accels;
        const gchar *icon_name;
        const gchar *tooltip;
 
-       g_return_val_if_fail (TEPL_IS_ACTION_INFO_STORE (store), NULL);
+       g_return_val_if_fail (AMTK_IS_ACTION_INFO_STORE (store), NULL);
        g_return_val_if_fail (action_name != NULL, NULL);
 
        action_info = g_hash_table_lookup (store->priv->hash_table, action_name);
@@ -386,12 +386,12 @@ tepl_action_info_store_create_menu_item (TeplActionInfoStore *store,
        gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_item), action_name);
 
        gtk_menu_item_set_use_underline (menu_item, TRUE);
-       gtk_menu_item_set_label (menu_item, tepl_action_info_get_label (action_info));
+       gtk_menu_item_set_label (menu_item, amtk_action_info_get_label (action_info));
 
        /* Set accel before setting icon, because
-        * tepl_menu_item_set_icon_name() adds a GtkBox.
+        * amtk_menu_item_set_icon_name() adds a GtkBox.
         */
-       accels = tepl_action_info_get_accels (action_info);
+       accels = amtk_action_info_get_accels (action_info);
        if (accels != NULL && accels[0] != NULL)
        {
                guint accel_key;
@@ -411,16 +411,16 @@ tepl_action_info_store_create_menu_item (TeplActionInfoStore *store,
                }
        }
 
-       icon_name = tepl_action_info_get_icon_name (action_info);
+       icon_name = amtk_action_info_get_icon_name (action_info);
        if (icon_name != NULL)
        {
-               tepl_menu_item_set_icon_name (menu_item, icon_name);
+               amtk_menu_item_set_icon_name (menu_item, icon_name);
        }
 
-       tooltip = tepl_action_info_get_tooltip (action_info);
+       tooltip = amtk_action_info_get_tooltip (action_info);
        if (tooltip != NULL)
        {
-               tepl_menu_item_set_long_description (menu_item, tooltip);
+               amtk_menu_item_set_long_description (menu_item, tooltip);
        }
 
        if (store->priv->app != NULL)
@@ -430,7 +430,7 @@ tepl_action_info_store_create_menu_item (TeplActionInfoStore *store,
                                                       accels);
        }
 
-       _tepl_action_info_set_used (action_info);
+       _amtk_action_info_set_used (action_info);
 
        return GTK_WIDGET (menu_item);
 }
@@ -441,33 +441,33 @@ check_used_cb (gpointer key,
               gpointer user_data)
 {
        const gchar *action_name = key;
-       const TeplActionInfo *action_info = value;
+       const AmtkActionInfo *action_info = value;
 
-       if (!_tepl_action_info_get_used (action_info))
+       if (!_amtk_action_info_get_used (action_info))
        {
-               g_warning ("TeplActionInfo with action_name='%s' has not been used.",
+               g_warning ("AmtkActionInfo with action_name='%s' has not been used.",
                           action_name);
        }
 }
 
 /**
- * tepl_action_info_store_check_all_used:
- * @store: a #TeplActionInfoStore.
+ * amtk_action_info_store_check_all_used:
+ * @store: a #AmtkActionInfoStore.
  *
- * Checks that all #TeplActionInfo's of @store have been used by
- * tepl_action_info_store_create_menu_item(). If not, a warning is printed and
+ * Checks that all #AmtkActionInfo's of @store have been used by
+ * amtk_action_info_store_create_menu_item(). If not, a warning is printed and
  * might indicate dead code.
  *
  * You probably want to call this function on the store returned by
- * tepl_application_get_app_action_info_store(). But it can also be useful for a
+ * amtk_application_get_app_action_info_store(). But it can also be useful for a
  * store provided by a library, to easily see which actions you don't use.
  *
  * Since: 2.0
  */
 void
-tepl_action_info_store_check_all_used (TeplActionInfoStore *store)
+amtk_action_info_store_check_all_used (AmtkActionInfoStore *store)
 {
-       g_return_if_fail (TEPL_IS_ACTION_INFO_STORE (store));
+       g_return_if_fail (AMTK_IS_ACTION_INFO_STORE (store));
 
        g_hash_table_foreach (store->priv->hash_table,
                              check_used_cb,
diff --git a/amtk/amtk-action-info-store.h b/amtk/amtk-action-info-store.h
new file mode 100644
index 0000000..4621cad
--- /dev/null
+++ b/amtk/amtk-action-info-store.h
@@ -0,0 +1,80 @@
+/*
+ * This file is part of Amtk, a text editor library.
+ *
+ * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
+ *
+ * Amtk is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Lesser General Public License as published by the
+ * Free Software Foundation; either version 2.1 of the License, or (at your
+ * option) any later version.
+ *
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ */
+
+#ifndef AMTK_ACTION_INFO_STORE_H
+#define AMTK_ACTION_INFO_STORE_H
+
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
+#endif
+
+#include <gtk/gtk.h>
+#include <amtk/amtk-types.h>
+
+G_BEGIN_DECLS
+
+#define AMTK_TYPE_ACTION_INFO_STORE             (amtk_action_info_store_get_type ())
+#define AMTK_ACTION_INFO_STORE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), 
AMTK_TYPE_ACTION_INFO_STORE, AmtkActionInfoStore))
+#define AMTK_ACTION_INFO_STORE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), 
AMTK_TYPE_ACTION_INFO_STORE, AmtkActionInfoStoreClass))
+#define AMTK_IS_ACTION_INFO_STORE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), 
AMTK_TYPE_ACTION_INFO_STORE))
+#define AMTK_IS_ACTION_INFO_STORE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), 
AMTK_TYPE_ACTION_INFO_STORE))
+#define AMTK_ACTION_INFO_STORE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), 
AMTK_TYPE_ACTION_INFO_STORE, AmtkActionInfoStoreClass))
+
+typedef struct _AmtkActionInfoStoreClass    AmtkActionInfoStoreClass;
+typedef struct _AmtkActionInfoStorePrivate  AmtkActionInfoStorePrivate;
+
+struct _AmtkActionInfoStore
+{
+       GObject parent;
+
+       AmtkActionInfoStorePrivate *priv;
+};
+
+struct _AmtkActionInfoStoreClass
+{
+       GObjectClass parent_class;
+
+       gpointer padding[12];
+};
+
+GType                  amtk_action_info_store_get_type                 (void) G_GNUC_CONST;
+
+AmtkActionInfoStore *  amtk_action_info_store_new                      (GtkApplication *application);
+
+GtkApplication *       amtk_action_info_store_get_application          (AmtkActionInfoStore *store);
+
+void                   amtk_action_info_store_add                      (AmtkActionInfoStore *store,
+                                                                        AmtkActionInfo      *info);
+
+void                   amtk_action_info_store_add_entries              (AmtkActionInfoStore       *store,
+                                                                        const AmtkActionInfoEntry *entries,
+                                                                        gint                       n_entries,
+                                                                        const gchar               
*translation_domain);
+
+const AmtkActionInfo * amtk_action_info_store_lookup                   (AmtkActionInfoStore *store,
+                                                                        const gchar         *action_name);
+
+GtkWidget *            amtk_action_info_store_create_menu_item         (AmtkActionInfoStore *store,
+                                                                        const gchar         *action_name);
+
+void                   amtk_action_info_store_check_all_used           (AmtkActionInfoStore *store);
+
+G_END_DECLS
+
+#endif /* AMTK_ACTION_INFO_STORE_H */
diff --git a/amtk/tepl-action-info.c b/amtk/amtk-action-info.c
similarity index 67%
rename from amtk/tepl-action-info.c
rename to amtk/amtk-action-info.c
index af9d7bd..dbe906e 100644
--- a/amtk/tepl-action-info.c
+++ b/amtk/amtk-action-info.c
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -18,29 +18,29 @@
  */
 
 #include "config.h"
-#include "tepl-action-info.h"
+#include "amtk-action-info.h"
 #include <glib/gi18n-lib.h>
-#include "tepl-utils.h"
+#include "amtk-utils.h"
 
 /**
  * SECTION:action-info
  * @Short_description: GAction information
- * @Title: TeplActionInfo
- * @See_also: #TeplActionInfoStore
+ * @Title: AmtkActionInfo
+ * @See_also: #AmtkActionInfoStore
  *
- * A #TeplActionInfo instance contains a set of information about a #GAction.
+ * A #AmtkActionInfo instance contains a set of information about a #GAction.
  * Those pieces of information are useful to create UI elements that trigger the
  * #GAction, for example a menu item or a toolbar item.
  *
  * When writing an XML file to create a #GMenu, with the format understood by
  * #GtkBuilder (see the class description of #GtkApplicationWindow), the
  * information in the XML file can be used only to create a #GMenu. The initial
- * goal with #TeplActionInfo and its related classes is to encode the
+ * goal with #AmtkActionInfo and its related classes is to encode the
  * information just once, and be able to create both a menu and a toolbar easily
  * (to have a traditional user interface).
  */
 
-struct _TeplActionInfo
+struct _AmtkActionInfo
 {
        gchar *action_name;
        gchar *icon_name;
@@ -58,14 +58,14 @@ struct _TeplActionInfo
        guint used : 1;
 };
 
-static void _tepl_action_info_free (TeplActionInfo *info);
+static void _amtk_action_info_free (AmtkActionInfo *info);
 
-G_DEFINE_BOXED_TYPE (TeplActionInfo, tepl_action_info,
-                    tepl_action_info_copy,
-                    _tepl_action_info_free)
+G_DEFINE_BOXED_TYPE (AmtkActionInfo, amtk_action_info,
+                    amtk_action_info_copy,
+                    _amtk_action_info_free)
 
 static void
-_tepl_action_info_free (TeplActionInfo *info)
+_amtk_action_info_free (AmtkActionInfo *info)
 {
        if (info != NULL)
        {
@@ -80,17 +80,17 @@ _tepl_action_info_free (TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_new:
+ * amtk_action_info_new:
  *
- * Returns: a new #TeplActionInfo.
+ * Returns: a new #AmtkActionInfo.
  * Since: 2.0
  */
-TeplActionInfo *
-tepl_action_info_new (void)
+AmtkActionInfo *
+amtk_action_info_new (void)
 {
-       TeplActionInfo *info;
+       AmtkActionInfo *info;
 
-       info = g_new0 (TeplActionInfo, 1);
+       info = g_new0 (AmtkActionInfo, 1);
        info->accels = g_malloc0 (sizeof (gchar *));
        info->ref_count = 1;
 
@@ -98,25 +98,25 @@ tepl_action_info_new (void)
 }
 
 /**
- * tepl_action_info_new_from_entry:
- * @info_entry: a #TeplActionInfoEntry.
+ * amtk_action_info_new_from_entry:
+ * @info_entry: a #AmtkActionInfoEntry.
  * @translation_domain: (nullable): a gettext domain, or %NULL.
  *
- * Creates a new #TeplActionInfo from a #TeplActionInfoEntry.
+ * Creates a new #AmtkActionInfo from a #AmtkActionInfoEntry.
  *
  * If @translation_domain is not %NULL, g_dgettext() is used to translate the
- * @label and @tooltip before setting them to the #TeplActionInfo.
+ * @label and @tooltip before setting them to the #AmtkActionInfo.
  *
- * Returns: a new #TeplActionInfo.
+ * Returns: a new #AmtkActionInfo.
  * Since: 2.0
  */
-TeplActionInfo *
-tepl_action_info_new_from_entry (const TeplActionInfoEntry *info_entry,
+AmtkActionInfo *
+amtk_action_info_new_from_entry (const AmtkActionInfoEntry *info_entry,
                                 const gchar               *translation_domain)
 {
-       TeplActionInfo *info;
+       AmtkActionInfo *info;
 
-       info = tepl_action_info_new ();
+       info = amtk_action_info_new ();
        info->action_name = g_strdup (info_entry->action_name);
        info->icon_name = g_strdup (info_entry->icon_name);
 
@@ -144,16 +144,16 @@ tepl_action_info_new_from_entry (const TeplActionInfoEntry *info_entry,
 }
 
 /**
- * tepl_action_info_ref:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_ref:
+ * @info: a #AmtkActionInfo.
  *
  * Increments the reference count of @info by one.
  *
  * Returns: the passed in @info.
  * Since: 2.0
  */
-TeplActionInfo *
-tepl_action_info_ref (TeplActionInfo *info)
+AmtkActionInfo *
+amtk_action_info_ref (AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, NULL);
 
@@ -163,8 +163,8 @@ tepl_action_info_ref (TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_unref:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_unref:
+ * @info: a #AmtkActionInfo.
  *
  * Decrements the reference count of @info by one. If the reference count drops
  * to 0, @info is freed.
@@ -172,7 +172,7 @@ tepl_action_info_ref (TeplActionInfo *info)
  * Since: 2.0
  */
 void
-tepl_action_info_unref (TeplActionInfo *info)
+amtk_action_info_unref (AmtkActionInfo *info)
 {
        g_return_if_fail (info != NULL);
 
@@ -180,46 +180,46 @@ tepl_action_info_unref (TeplActionInfo *info)
 
        if (info->ref_count == 0)
        {
-               _tepl_action_info_free (info);
+               _amtk_action_info_free (info);
        }
 }
 
 /**
- * tepl_action_info_copy:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_copy:
+ * @info: a #AmtkActionInfo.
  *
  * Returns: (transfer full): a copy of @info. The copy will have a reference
  * count of one.
  * Since: 2.0
  */
-TeplActionInfo *
-tepl_action_info_copy (const TeplActionInfo *info)
+AmtkActionInfo *
+amtk_action_info_copy (const AmtkActionInfo *info)
 {
-       TeplActionInfo *new_info;
+       AmtkActionInfo *new_info;
 
        g_return_val_if_fail (info != NULL, NULL);
 
-       new_info = tepl_action_info_new ();
+       new_info = amtk_action_info_new ();
 
        new_info->action_name = g_strdup (info->action_name);
        new_info->icon_name = g_strdup (info->icon_name);
        new_info->label = g_strdup (info->label);
        new_info->tooltip = g_strdup (info->tooltip);
 
-       tepl_action_info_set_accels (new_info, (const gchar * const *)info->accels);
+       amtk_action_info_set_accels (new_info, (const gchar * const *)info->accels);
 
        return new_info;
 }
 
 /**
- * tepl_action_info_get_action_name:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_get_action_name:
+ * @info: a #AmtkActionInfo.
  *
  * Returns: (nullable): the action name, or %NULL. Example: `"win.save"`.
  * Since: 2.0
  */
 const gchar *
-tepl_action_info_get_action_name (const TeplActionInfo *info)
+amtk_action_info_get_action_name (const AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, NULL);
 
@@ -227,8 +227,8 @@ tepl_action_info_get_action_name (const TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_set_action_name:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_set_action_name:
+ * @info: a #AmtkActionInfo.
  * @action_name: the action name.
  *
  * Sets the action name, for example `"win.save"`.
@@ -236,7 +236,7 @@ tepl_action_info_get_action_name (const TeplActionInfo *info)
  * Since: 2.0
  */
 void
-tepl_action_info_set_action_name (TeplActionInfo *info,
+amtk_action_info_set_action_name (AmtkActionInfo *info,
                                  const gchar    *action_name)
 {
        g_return_if_fail (info != NULL);
@@ -247,14 +247,14 @@ tepl_action_info_set_action_name (TeplActionInfo *info,
 }
 
 /**
- * tepl_action_info_get_icon_name:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_get_icon_name:
+ * @info: a #AmtkActionInfo.
  *
  * Returns: (nullable): the icon name, or %NULL.
  * Since: 2.0
  */
 const gchar *
-tepl_action_info_get_icon_name (const TeplActionInfo *info)
+amtk_action_info_get_icon_name (const AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, NULL);
 
@@ -262,14 +262,14 @@ tepl_action_info_get_icon_name (const TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_set_icon_name:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_set_icon_name:
+ * @info: a #AmtkActionInfo.
  * @icon_name: (nullable): the icon name, or %NULL.
  *
  * Since: 2.0
  */
 void
-tepl_action_info_set_icon_name (TeplActionInfo *info,
+amtk_action_info_set_icon_name (AmtkActionInfo *info,
                                const gchar    *icon_name)
 {
        g_return_if_fail (info != NULL);
@@ -279,14 +279,14 @@ tepl_action_info_set_icon_name (TeplActionInfo *info,
 }
 
 /**
- * tepl_action_info_get_label:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_get_label:
+ * @info: a #AmtkActionInfo.
  *
  * Returns: (nullable): the label (i.e. a short description), or %NULL.
  * Since: 2.0
  */
 const gchar *
-tepl_action_info_get_label (const TeplActionInfo *info)
+amtk_action_info_get_label (const AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, NULL);
 
@@ -294,14 +294,14 @@ tepl_action_info_get_label (const TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_set_label:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_set_label:
+ * @info: a #AmtkActionInfo.
  * @label: (nullable): the label (i.e. a short description), or %NULL.
  *
  * Since: 2.0
  */
 void
-tepl_action_info_set_label (TeplActionInfo *info,
+amtk_action_info_set_label (AmtkActionInfo *info,
                            const gchar    *label)
 {
        g_return_if_fail (info != NULL);
@@ -311,14 +311,14 @@ tepl_action_info_set_label (TeplActionInfo *info,
 }
 
 /**
- * tepl_action_info_get_tooltip:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_get_tooltip:
+ * @info: a #AmtkActionInfo.
  *
  * Returns: (nullable): the tooltip (i.e. a long description), or %NULL.
  * Since: 2.0
  */
 const gchar *
-tepl_action_info_get_tooltip (const TeplActionInfo *info)
+amtk_action_info_get_tooltip (const AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, NULL);
 
@@ -326,14 +326,14 @@ tepl_action_info_get_tooltip (const TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_set_tooltip:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_set_tooltip:
+ * @info: a #AmtkActionInfo.
  * @tooltip: (nullable): the tooltip (i.e. a long description), or %NULL.
  *
  * Since: 2.0
  */
 void
-tepl_action_info_set_tooltip (TeplActionInfo *info,
+amtk_action_info_set_tooltip (AmtkActionInfo *info,
                              const gchar    *tooltip)
 {
        g_return_if_fail (info != NULL);
@@ -343,8 +343,8 @@ tepl_action_info_set_tooltip (TeplActionInfo *info,
 }
 
 /**
- * tepl_action_info_get_accels:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_get_accels:
+ * @info: a #AmtkActionInfo.
  *
  * Returns the accelerators. This function never returns %NULL, it always
  * returns a %NULL-terminated array, to be suitable for
@@ -355,7 +355,7 @@ tepl_action_info_set_tooltip (TeplActionInfo *info,
  * Since: 2.0
  */
 const gchar * const *
-tepl_action_info_get_accels (const TeplActionInfo *info)
+amtk_action_info_get_accels (const AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, NULL);
 
@@ -365,8 +365,8 @@ tepl_action_info_get_accels (const TeplActionInfo *info)
 }
 
 /**
- * tepl_action_info_set_accels:
- * @info: a #TeplActionInfo.
+ * amtk_action_info_set_accels:
+ * @info: a #AmtkActionInfo.
  * @accels: (array zero-terminated=1): a %NULL-terminated array of accelerators
  * in the format understood by gtk_accelerator_parse().
  *
@@ -378,18 +378,18 @@ tepl_action_info_get_accels (const TeplActionInfo *info)
  * Since: 2.0
  */
 void
-tepl_action_info_set_accels (TeplActionInfo      *info,
+amtk_action_info_set_accels (AmtkActionInfo      *info,
                             const gchar * const *accels)
 {
        g_return_if_fail (info != NULL);
        g_return_if_fail (accels != NULL);
 
        g_strfreev (info->accels);
-       info->accels = _tepl_utils_strv_copy (accels);
+       info->accels = _amtk_utils_strv_copy (accels);
 }
 
 gboolean
-_tepl_action_info_get_used (const TeplActionInfo *info)
+_amtk_action_info_get_used (const AmtkActionInfo *info)
 {
        g_return_val_if_fail (info != NULL, FALSE);
 
@@ -397,7 +397,7 @@ _tepl_action_info_get_used (const TeplActionInfo *info)
 }
 
 void
-_tepl_action_info_set_used (TeplActionInfo *info)
+_amtk_action_info_set_used (AmtkActionInfo *info)
 {
        g_return_if_fail (info != NULL);
 
diff --git a/amtk/tepl-menu-shell.c b/amtk/amtk-menu-shell.c
similarity index 57%
rename from amtk/tepl-menu-shell.c
rename to amtk/amtk-menu-shell.c
index ddf641f..5585461 100644
--- a/amtk/tepl-menu-shell.c
+++ b/amtk/amtk-menu-shell.c
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2016, 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,23 +17,23 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "tepl-menu-shell.h"
+#include "amtk-menu-shell.h"
 
 /**
  * SECTION:menu-shell
  * @Short_description: An extension of GtkMenuShell
- * @Title: TeplMenuShell
+ * @Title: AmtkMenuShell
  *
- * #TeplMenuShell extends the #GtkMenuShell abstract class with the
- * #TeplMenuShell::menu-item-selected and #TeplMenuShell::menu-item-deselected
+ * #AmtkMenuShell extends the #GtkMenuShell abstract class with the
+ * #AmtkMenuShell::menu-item-selected and #AmtkMenuShell::menu-item-deselected
  * convenience signals.
  *
  * One possible use-case is to push/pop longer descriptions of menu items to a
  * #GtkStatusbar, exactly like
- * tepl_application_window_connect_menu_to_statusbar() does.
+ * amtk_application_window_connect_menu_to_statusbar() does.
  */
 
-struct _TeplMenuShellPrivate
+struct _AmtkMenuShellPrivate
 {
        GtkMenuShell *gtk_menu_shell;
 };
@@ -52,35 +52,35 @@ enum
        N_SIGNALS
 };
 
-#define TEPL_MENU_SHELL_KEY "tepl-menu-shell-key"
+#define AMTK_MENU_SHELL_KEY "amtk-menu-shell-key"
 
 static GParamSpec *properties[N_PROPERTIES];
 static guint signals[N_SIGNALS];
 
-G_DEFINE_TYPE_WITH_PRIVATE (TeplMenuShell, tepl_menu_shell, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (AmtkMenuShell, amtk_menu_shell, G_TYPE_OBJECT)
 
 /* Prototypes */
-static void connect_menu_shell         (TeplMenuShell *tepl_menu_shell,
+static void connect_menu_shell         (AmtkMenuShell *amtk_menu_shell,
                                         GtkMenuShell  *gtk_menu_shell);
 
-static void disconnect_menu_shell      (TeplMenuShell *tepl_menu_shell,
+static void disconnect_menu_shell      (AmtkMenuShell *amtk_menu_shell,
                                         GtkMenuShell  *gtk_menu_shell);
 
 static void
 menu_item_select_cb (GtkMenuItem *menu_item,
                     gpointer     user_data)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (user_data);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (user_data);
        GtkWidget *submenu;
 
        submenu = gtk_menu_item_get_submenu (menu_item);
 
        if (GTK_IS_MENU_SHELL (submenu))
        {
-               connect_menu_shell (tepl_menu_shell, GTK_MENU_SHELL (submenu));
+               connect_menu_shell (amtk_menu_shell, GTK_MENU_SHELL (submenu));
        }
 
-       g_signal_emit (tepl_menu_shell,
+       g_signal_emit (amtk_menu_shell,
                       signals[SIGNAL_MENU_ITEM_SELECTED], 0,
                       menu_item);
 }
@@ -89,49 +89,49 @@ static void
 menu_item_deselect_cb (GtkMenuItem *menu_item,
                       gpointer     user_data)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (user_data);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (user_data);
        GtkWidget *submenu;
 
        submenu = gtk_menu_item_get_submenu (menu_item);
 
        if (GTK_IS_MENU_SHELL (submenu))
        {
-               disconnect_menu_shell (tepl_menu_shell, GTK_MENU_SHELL (submenu));
+               disconnect_menu_shell (amtk_menu_shell, GTK_MENU_SHELL (submenu));
        }
 
-       g_signal_emit (tepl_menu_shell,
+       g_signal_emit (amtk_menu_shell,
                       signals[SIGNAL_MENU_ITEM_DESELECTED], 0,
                       menu_item);
 }
 
 static void
-connect_menu_item (TeplMenuShell *tepl_menu_shell,
+connect_menu_item (AmtkMenuShell *amtk_menu_shell,
                   GtkMenuItem   *menu_item)
 {
        g_signal_connect_object (menu_item,
                                 "select",
                                 G_CALLBACK (menu_item_select_cb),
-                                tepl_menu_shell,
+                                amtk_menu_shell,
                                 0);
 
        g_signal_connect_object (menu_item,
                                 "deselect",
                                 G_CALLBACK (menu_item_deselect_cb),
-                                tepl_menu_shell,
+                                amtk_menu_shell,
                                 0);
 }
 
 static void
-disconnect_menu_item (TeplMenuShell *tepl_menu_shell,
+disconnect_menu_item (AmtkMenuShell *amtk_menu_shell,
                      GtkMenuItem   *menu_item)
 {
        g_signal_handlers_disconnect_by_func (menu_item,
                                              menu_item_select_cb,
-                                             tepl_menu_shell);
+                                             amtk_menu_shell);
 
        g_signal_handlers_disconnect_by_func (menu_item,
                                              menu_item_deselect_cb,
-                                             tepl_menu_shell);
+                                             amtk_menu_shell);
 }
 
 static void
@@ -140,11 +140,11 @@ insert_cb (GtkMenuShell *gtk_menu_shell,
           gint          position,
           gpointer      user_data)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (user_data);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (user_data);
 
        if (GTK_IS_MENU_ITEM (child))
        {
-               connect_menu_item (tepl_menu_shell, GTK_MENU_ITEM (child));
+               connect_menu_item (amtk_menu_shell, GTK_MENU_ITEM (child));
        }
 }
 
@@ -153,16 +153,16 @@ remove_cb (GtkContainer *container,
           GtkWidget    *child,
           gpointer      user_data)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (user_data);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (user_data);
 
        if (GTK_IS_MENU_ITEM (child))
        {
-               disconnect_menu_item (tepl_menu_shell, GTK_MENU_ITEM (child));
+               disconnect_menu_item (amtk_menu_shell, GTK_MENU_ITEM (child));
        }
 }
 
 static void
-connect_menu_shell (TeplMenuShell *tepl_menu_shell,
+connect_menu_shell (AmtkMenuShell *amtk_menu_shell,
                    GtkMenuShell  *gtk_menu_shell)
 {
        GList *children;
@@ -176,7 +176,7 @@ connect_menu_shell (TeplMenuShell *tepl_menu_shell,
 
                if (GTK_IS_MENU_ITEM (menu_item))
                {
-                       connect_menu_item (tepl_menu_shell, menu_item);
+                       connect_menu_item (amtk_menu_shell, menu_item);
                }
        }
 
@@ -185,18 +185,18 @@ connect_menu_shell (TeplMenuShell *tepl_menu_shell,
        g_signal_connect_object (gtk_menu_shell,
                                 "insert",
                                 G_CALLBACK (insert_cb),
-                                tepl_menu_shell,
+                                amtk_menu_shell,
                                 0);
 
        g_signal_connect_object (gtk_menu_shell,
                                 "remove",
                                 G_CALLBACK (remove_cb),
-                                tepl_menu_shell,
+                                amtk_menu_shell,
                                 0);
 }
 
 static void
-disconnect_menu_shell (TeplMenuShell *tepl_menu_shell,
+disconnect_menu_shell (AmtkMenuShell *amtk_menu_shell,
                       GtkMenuShell  *gtk_menu_shell)
 {
        GList *children;
@@ -210,7 +210,7 @@ disconnect_menu_shell (TeplMenuShell *tepl_menu_shell,
 
                if (GTK_IS_MENU_ITEM (menu_item))
                {
-                       disconnect_menu_item (tepl_menu_shell, menu_item);
+                       disconnect_menu_item (amtk_menu_shell, menu_item);
                }
        }
 
@@ -218,36 +218,36 @@ disconnect_menu_shell (TeplMenuShell *tepl_menu_shell,
 
        g_signal_handlers_disconnect_by_func (gtk_menu_shell,
                                              insert_cb,
-                                             tepl_menu_shell);
+                                             amtk_menu_shell);
 
        g_signal_handlers_disconnect_by_func (gtk_menu_shell,
                                              remove_cb,
-                                             tepl_menu_shell);
+                                             amtk_menu_shell);
 }
 
 static void
-set_menu_shell (TeplMenuShell *tepl_menu_shell,
+set_menu_shell (AmtkMenuShell *amtk_menu_shell,
                GtkMenuShell  *gtk_menu_shell)
 {
-       g_assert (tepl_menu_shell->priv->gtk_menu_shell == NULL);
+       g_assert (amtk_menu_shell->priv->gtk_menu_shell == NULL);
        g_return_if_fail (GTK_IS_MENU_SHELL (gtk_menu_shell));
 
-       tepl_menu_shell->priv->gtk_menu_shell = gtk_menu_shell;
-       connect_menu_shell (tepl_menu_shell, gtk_menu_shell);
+       amtk_menu_shell->priv->gtk_menu_shell = gtk_menu_shell;
+       connect_menu_shell (amtk_menu_shell, gtk_menu_shell);
 }
 
 static void
-tepl_menu_shell_get_property (GObject    *object,
+amtk_menu_shell_get_property (GObject    *object,
                              guint       prop_id,
                              GValue     *value,
                              GParamSpec *pspec)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (object);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (object);
 
        switch (prop_id)
        {
                case PROP_MENU_SHELL:
-                       g_value_set_object (value, tepl_menu_shell_get_menu_shell (tepl_menu_shell));
+                       g_value_set_object (value, amtk_menu_shell_get_menu_shell (amtk_menu_shell));
                        break;
 
                default:
@@ -257,17 +257,17 @@ tepl_menu_shell_get_property (GObject    *object,
 }
 
 static void
-tepl_menu_shell_set_property (GObject      *object,
+amtk_menu_shell_set_property (GObject      *object,
                              guint         prop_id,
                              const GValue *value,
                              GParamSpec   *pspec)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (object);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (object);
 
        switch (prop_id)
        {
                case PROP_MENU_SHELL:
-                       set_menu_shell (tepl_menu_shell, g_value_get_object (value));
+                       set_menu_shell (amtk_menu_shell, g_value_get_object (value));
                        break;
 
                default:
@@ -277,26 +277,26 @@ tepl_menu_shell_set_property (GObject      *object,
 }
 
 static void
-tepl_menu_shell_dispose (GObject *object)
+amtk_menu_shell_dispose (GObject *object)
 {
-       TeplMenuShell *tepl_menu_shell = TEPL_MENU_SHELL (object);
+       AmtkMenuShell *amtk_menu_shell = AMTK_MENU_SHELL (object);
 
-       tepl_menu_shell->priv->gtk_menu_shell = NULL;
+       amtk_menu_shell->priv->gtk_menu_shell = NULL;
 
-       G_OBJECT_CLASS (tepl_menu_shell_parent_class)->dispose (object);
+       G_OBJECT_CLASS (amtk_menu_shell_parent_class)->dispose (object);
 }
 
 static void
-tepl_menu_shell_class_init (TeplMenuShellClass *klass)
+amtk_menu_shell_class_init (AmtkMenuShellClass *klass)
 {
        GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-       object_class->get_property = tepl_menu_shell_get_property;
-       object_class->set_property = tepl_menu_shell_set_property;
-       object_class->dispose = tepl_menu_shell_dispose;
+       object_class->get_property = amtk_menu_shell_get_property;
+       object_class->set_property = amtk_menu_shell_set_property;
+       object_class->dispose = amtk_menu_shell_dispose;
 
        /**
-        * TeplMenuShell:menu-shell:
+        * AmtkMenuShell:menu-shell:
         *
         * The #GtkMenuShell.
         *
@@ -314,13 +314,13 @@ tepl_menu_shell_class_init (TeplMenuShellClass *klass)
        g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 
        /**
-        * TeplMenuShell::menu-item-selected:
-        * @tepl_menu_shell: the #TeplMenuShell emitting the signal.
+        * AmtkMenuShell::menu-item-selected:
+        * @amtk_menu_shell: the #AmtkMenuShell emitting the signal.
         * @menu_item: the #GtkMenuItem that has been selected.
         *
         * The ::menu-item-selected signal is emitted when the
         * #GtkMenuItem::select signal is emitted on a #GtkMenuItem belonging
-        * (directly or indirectly through submenus) to @tepl_menu_shell.
+        * (directly or indirectly through submenus) to @amtk_menu_shell.
         *
         * Since: 2.0
         */
@@ -328,19 +328,19 @@ tepl_menu_shell_class_init (TeplMenuShellClass *klass)
                g_signal_new ("menu-item-selected",
                              G_TYPE_FROM_CLASS (klass),
                              G_SIGNAL_RUN_FIRST,
-                             G_STRUCT_OFFSET (TeplMenuShellClass, menu_item_selected),
+                             G_STRUCT_OFFSET (AmtkMenuShellClass, menu_item_selected),
                              NULL, NULL, NULL,
                              G_TYPE_NONE,
                              1, GTK_TYPE_MENU_ITEM);
 
        /**
-        * TeplMenuShell::menu-item-deselected:
-        * @tepl_menu_shell: the #TeplMenuShell emitting the signal.
+        * AmtkMenuShell::menu-item-deselected:
+        * @amtk_menu_shell: the #AmtkMenuShell emitting the signal.
         * @menu_item: the #GtkMenuItem that has been deselected.
         *
         * The ::menu-item-deselected signal is emitted when the
         * #GtkMenuItem::deselect signal is emitted on a #GtkMenuItem belonging
-        * (directly or indirectly through submenus) to @tepl_menu_shell.
+        * (directly or indirectly through submenus) to @amtk_menu_shell.
         *
         * Since: 2.0
         */
@@ -348,66 +348,66 @@ tepl_menu_shell_class_init (TeplMenuShellClass *klass)
                g_signal_new ("menu-item-deselected",
                              G_TYPE_FROM_CLASS (klass),
                              G_SIGNAL_RUN_FIRST,
-                             G_STRUCT_OFFSET (TeplMenuShellClass, menu_item_deselected),
+                             G_STRUCT_OFFSET (AmtkMenuShellClass, menu_item_deselected),
                              NULL, NULL, NULL,
                              G_TYPE_NONE,
                              1, GTK_TYPE_MENU_ITEM);
 }
 
 static void
-tepl_menu_shell_init (TeplMenuShell *tepl_menu_shell)
+amtk_menu_shell_init (AmtkMenuShell *amtk_menu_shell)
 {
-       tepl_menu_shell->priv = tepl_menu_shell_get_instance_private (tepl_menu_shell);
+       amtk_menu_shell->priv = amtk_menu_shell_get_instance_private (amtk_menu_shell);
 }
 
 /**
- * tepl_menu_shell_get_from_gtk_menu_shell:
+ * amtk_menu_shell_get_from_gtk_menu_shell:
  * @gtk_menu_shell: a #GtkMenuShell.
  *
- * Returns the #TeplMenuShell of @gtk_menu_shell. The returned object is
+ * Returns the #AmtkMenuShell of @gtk_menu_shell. The returned object is
  * guaranteed to be the same for the lifetime of @gtk_menu_shell.
  *
- * Returns: (transfer none): the #TeplMenuShell of @gtk_menu_shell.
+ * Returns: (transfer none): the #AmtkMenuShell of @gtk_menu_shell.
  * Since: 2.0
  */
-TeplMenuShell *
-tepl_menu_shell_get_from_gtk_menu_shell (GtkMenuShell *gtk_menu_shell)
+AmtkMenuShell *
+amtk_menu_shell_get_from_gtk_menu_shell (GtkMenuShell *gtk_menu_shell)
 {
-       TeplMenuShell *tepl_menu_shell;
+       AmtkMenuShell *amtk_menu_shell;
 
        g_return_val_if_fail (GTK_IS_MENU_SHELL (gtk_menu_shell), NULL);
 
-       tepl_menu_shell = g_object_get_data (G_OBJECT (gtk_menu_shell), TEPL_MENU_SHELL_KEY);
+       amtk_menu_shell = g_object_get_data (G_OBJECT (gtk_menu_shell), AMTK_MENU_SHELL_KEY);
 
-       if (tepl_menu_shell == NULL)
+       if (amtk_menu_shell == NULL)
        {
-               tepl_menu_shell = g_object_new (TEPL_TYPE_MENU_SHELL,
+               amtk_menu_shell = g_object_new (AMTK_TYPE_MENU_SHELL,
                                                "menu-shell", gtk_menu_shell,
                                                NULL);
 
                g_object_set_data_full (G_OBJECT (gtk_menu_shell),
-                                       TEPL_MENU_SHELL_KEY,
-                                       tepl_menu_shell,
+                                       AMTK_MENU_SHELL_KEY,
+                                       amtk_menu_shell,
                                        g_object_unref);
        }
 
-       g_return_val_if_fail (TEPL_IS_MENU_SHELL (tepl_menu_shell), NULL);
-       return tepl_menu_shell;
+       g_return_val_if_fail (AMTK_IS_MENU_SHELL (amtk_menu_shell), NULL);
+       return amtk_menu_shell;
 }
 
 /**
- * tepl_menu_shell_get_menu_shell:
- * @tepl_menu_shell: a #TeplMenuShell.
+ * amtk_menu_shell_get_menu_shell:
+ * @amtk_menu_shell: a #AmtkMenuShell.
  *
- * Returns: (transfer none): the #GtkMenuShell of @tepl_menu_shell.
+ * Returns: (transfer none): the #GtkMenuShell of @amtk_menu_shell.
  * Since: 2.0
  */
 GtkMenuShell *
-tepl_menu_shell_get_menu_shell (TeplMenuShell *tepl_menu_shell)
+amtk_menu_shell_get_menu_shell (AmtkMenuShell *amtk_menu_shell)
 {
-       g_return_val_if_fail (TEPL_IS_MENU_SHELL (tepl_menu_shell), NULL);
+       g_return_val_if_fail (AMTK_IS_MENU_SHELL (amtk_menu_shell), NULL);
 
-       return tepl_menu_shell->priv->gtk_menu_shell;
+       return amtk_menu_shell->priv->gtk_menu_shell;
 }
 
 /* ex:set ts=8 noet: */
diff --git a/amtk/amtk-menu-shell.h b/amtk/amtk-menu-shell.h
new file mode 100644
index 0000000..668ef44
--- /dev/null
+++ b/amtk/amtk-menu-shell.h
@@ -0,0 +1,74 @@
+/*
+ * This file is part of Amtk, a text editor library.
+ *
+ * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
+ *
+ * Amtk is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Lesser General Public License as published by the
+ * Free Software Foundation; either version 2.1 of the License, or (at your
+ * option) any later version.
+ *
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ */
+
+#ifndef AMTK_MENU_SHELL_H
+#define AMTK_MENU_SHELL_H
+
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
+#endif
+
+#include <gtk/gtk.h>
+#include <amtk/amtk-types.h>
+
+G_BEGIN_DECLS
+
+#define AMTK_TYPE_MENU_SHELL             (amtk_menu_shell_get_type ())
+#define AMTK_MENU_SHELL(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), AMTK_TYPE_MENU_SHELL, 
AmtkMenuShell))
+#define AMTK_MENU_SHELL_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), AMTK_TYPE_MENU_SHELL, 
AmtkMenuShellClass))
+#define AMTK_IS_MENU_SHELL(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AMTK_TYPE_MENU_SHELL))
+#define AMTK_IS_MENU_SHELL_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), AMTK_TYPE_MENU_SHELL))
+#define AMTK_MENU_SHELL_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), AMTK_TYPE_MENU_SHELL, 
AmtkMenuShellClass))
+
+typedef struct _AmtkMenuShellClass    AmtkMenuShellClass;
+typedef struct _AmtkMenuShellPrivate  AmtkMenuShellPrivate;
+
+struct _AmtkMenuShell
+{
+       GObject parent;
+
+       AmtkMenuShellPrivate *priv;
+};
+
+struct _AmtkMenuShellClass
+{
+       GObjectClass parent_class;
+
+       /* Signals */
+
+       void (* menu_item_selected)     (AmtkMenuShell *amtk_menu_shell,
+                                        GtkMenuItem   *menu_item);
+
+       void (* menu_item_deselected)   (AmtkMenuShell *amtk_menu_shell,
+                                        GtkMenuItem   *menu_item);
+
+       gpointer padding[12];
+};
+
+GType          amtk_menu_shell_get_type                (void) G_GNUC_CONST;
+
+AmtkMenuShell *        amtk_menu_shell_get_from_gtk_menu_shell (GtkMenuShell *gtk_menu_shell);
+
+GtkMenuShell * amtk_menu_shell_get_menu_shell          (AmtkMenuShell *amtk_menu_shell);
+
+G_END_DECLS
+
+#endif /* AMTK_MENU_SHELL_H */
+
+/* ex:set ts=8 noet: */
diff --git a/amtk/tepl.h b/amtk/amtk.h
similarity index 53%
rename from amtk/tepl.h
rename to amtk/amtk.h
index 0f0f0d7..36b031d 100644
--- a/amtk/tepl.h
+++ b/amtk/amtk.h
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,20 +17,20 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEPL_H
-#define TEPL_H
+#ifndef AMTK_H
+#define AMTK_H
 
-#define TEPL_H_INSIDE
+#define AMTK_H_INSIDE
 
-#include <tepl/tepl-types.h>
+#include <amtk/amtk-types.h>
 
-#include <tepl/tepl-action-info.h>
-#include <tepl/tepl-action-info-store.h>
-#include <tepl/tepl-action-info-central-store.h>
-#include <tepl/tepl-action-map.h>
-#include <tepl/tepl-menu-item.h>
-#include <tepl/tepl-menu-shell.h>
+#include <amtk/amtk-action-info.h>
+#include <amtk/amtk-action-info-store.h>
+#include <amtk/amtk-action-info-central-store.h>
+#include <amtk/amtk-action-map.h>
+#include <amtk/amtk-menu-item.h>
+#include <amtk/amtk-menu-shell.h>
 
-#undef TEPL_H_INSIDE
+#undef AMTK_H_INSIDE
 
-#endif /* TEPL_H */
+#endif /* AMTK_H */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/amtk/tepl-action-info-central-store.c b/amtk/amtk-action-info-central-store.c
similarity index 51%
rename from amtk/tepl-action-info-central-store.c
rename to amtk/amtk-action-info-central-store.c
index ba607aa..d5bda48 100644
--- a/amtk/tepl-action-info-central-store.c
+++ b/amtk/amtk-action-info-central-store.c
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,36 +17,36 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "tepl-action-info-central-store.h"
-#include "tepl-action-info.h"
+#include "amtk-action-info-central-store.h"
+#include "amtk-action-info.h"
 
 /**
  * SECTION:action-info-central-store
  * @Short_description: Aggregation of all TeplActionInfoStore's
  * @Title: TeplActionInfoCentralStore
  * @See_also: #TeplActionInfoStore
  *
  * #TeplActionInfoCentralStore is a singleton class containing the aggregation
  * of all #TeplActionInfoStore's. Each time a #TeplActionInfo is added to a
  * #TeplActionInfoStore, it is also added to the #TeplActionInfoCentralStore.
  */
 
 /* API design:
  *
  * Why both TeplActionInfoStore and TeplActionInfoCentralStore are needed?
  *
  * Advantages of TeplActionInfoStore:
  * - tepl_action_info_store_new() takes an optional GtkApplication parameter. It
  *   doesn't rely on g_application_get_default() (calling
  *   g_application_get_default() in a library is not really a good practice I
  *   think. In theory an app can have several GApplication instances).
- * - tepl_action_info_store_check_all_used()
+ * - amtk_action_info_store_check_all_used()
  *
  * Advantages of TeplActionInfoCentralStore:
  * - The central store checks if there are no duplicated action names
  *   (globally).
  * - [For the menu bar, easy to retrieve the tooltip to show it in the
  *   statusbar.] No longer relevant with tepl_menu_item_get_long_description().
  *
  * If there was only one of the two classes, hacks would be needed to achieve
  * the above items. So by having the two classes, we have the best of both
@@ -54,79 +54,79 @@
  * big.
  */
 
-struct _TeplActionInfoCentralStorePrivate
+struct _AmtkActionInfoCentralStorePrivate
 {
        /* Key: owned gchar*: action name.
         * Value: owned TeplActionInfo.
         */
        GHashTable *hash_table;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (TeplActionInfoCentralStore, tepl_action_info_central_store, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (AmtkActionInfoCentralStore, amtk_action_info_central_store, G_TYPE_OBJECT)
 
 static void
-tepl_action_info_central_store_finalize (GObject *object)
+amtk_action_info_central_store_finalize (GObject *object)
 {
-       TeplActionInfoCentralStore *central_store = TEPL_ACTION_INFO_CENTRAL_STORE (object);
+       AmtkActionInfoCentralStore *central_store = AMTK_ACTION_INFO_CENTRAL_STORE (object);
 
        g_hash_table_unref (central_store->priv->hash_table);
 
-       G_OBJECT_CLASS (tepl_action_info_central_store_parent_class)->finalize (object);
+       G_OBJECT_CLASS (amtk_action_info_central_store_parent_class)->finalize (object);
 }
 
 static void
-tepl_action_info_central_store_class_init (TeplActionInfoCentralStoreClass *klass)
+amtk_action_info_central_store_class_init (AmtkActionInfoCentralStoreClass *klass)
 {
        GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-       object_class->finalize = tepl_action_info_central_store_finalize;
+       object_class->finalize = amtk_action_info_central_store_finalize;
 }
 
 static void
-tepl_action_info_central_store_init (TeplActionInfoCentralStore *central_store)
+amtk_action_info_central_store_init (AmtkActionInfoCentralStore *central_store)
 {
-       central_store->priv = tepl_action_info_central_store_get_instance_private (central_store);
+       central_store->priv = amtk_action_info_central_store_get_instance_private (central_store);
 
        central_store->priv->hash_table = g_hash_table_new_full (g_str_hash,
                                                                 g_str_equal,
                                                                 g_free,
-                                                                (GDestroyNotify) tepl_action_info_unref);
+                                                                (GDestroyNotify) amtk_action_info_unref);
 }
 
 /**
- * tepl_action_info_central_store_get_instance:
+ * amtk_action_info_central_store_get_instance:
  *
  * Returns: (transfer none): the #TeplActionInfoCentralStore singleton instance.
  * Since: 2.0
  */
-TeplActionInfoCentralStore *
-tepl_action_info_central_store_get_instance (void)
+AmtkActionInfoCentralStore *
+amtk_action_info_central_store_get_instance (void)
 {
-       static TeplActionInfoCentralStore *instance = NULL;
+       static AmtkActionInfoCentralStore *instance = NULL;
 
        if (G_UNLIKELY (instance == NULL))
        {
-               instance = g_object_new (TEPL_TYPE_ACTION_INFO_CENTRAL_STORE, NULL);
+               instance = g_object_new (AMTK_TYPE_ACTION_INFO_CENTRAL_STORE, NULL);
        }
 
        return instance;
 }
 
 void
-_tepl_action_info_central_store_add (TeplActionInfoCentralStore *central_store,
-                                    TeplActionInfo             *info)
+_amtk_action_info_central_store_add (AmtkActionInfoCentralStore *central_store,
+                                    AmtkActionInfo             *info)
 {
        const gchar *action_name;
 
-       g_return_if_fail (TEPL_IS_ACTION_INFO_CENTRAL_STORE (central_store));
+       g_return_if_fail (AMTK_IS_ACTION_INFO_CENTRAL_STORE (central_store));
        g_return_if_fail (info != NULL);
 
-       action_name = tepl_action_info_get_action_name (info);
+       action_name = amtk_action_info_get_action_name (info);
        g_return_if_fail (action_name != NULL);
 
        if (g_hash_table_lookup (central_store->priv->hash_table, action_name) != NULL)
        {
-               g_warning ("The TeplActionInfoCentralStore already contains a TeplActionInfo "
+               g_warning ("The AmtkActionInfoCentralStore already contains a AmtkActionInfo "
                           "with the action name “%s”. Libraries must namespace their action names.",
                           action_name);
                return;
@@ -134,22 +134,22 @@ _tepl_action_info_central_store_add (TeplActionInfoCentralStore *central_store,
 
        g_hash_table_insert (central_store->priv->hash_table,
                             g_strdup (action_name),
-                            tepl_action_info_ref (info));
+                            amtk_action_info_ref (info));
 }
 
 /**
- * tepl_action_info_central_store_lookup:
- * @central_store: a #TeplActionInfoCentralStore.
+ * amtk_action_info_central_store_lookup:
+ * @central_store: a #AmtkActionInfoCentralStore.
  * @action_name: an action name.
  *
  * Returns: (transfer none): the found #TeplActionInfo, or %NULL.
  * Since: 2.0
  */
-const TeplActionInfo *
-tepl_action_info_central_store_lookup (TeplActionInfoCentralStore *central_store,
+const AmtkActionInfo *
+amtk_action_info_central_store_lookup (AmtkActionInfoCentralStore *central_store,
                                       const gchar                *action_name)
 {
-       g_return_val_if_fail (TEPL_IS_ACTION_INFO_CENTRAL_STORE (central_store), NULL);
+       g_return_val_if_fail (AMTK_IS_ACTION_INFO_CENTRAL_STORE (central_store), NULL);
        g_return_val_if_fail (action_name != NULL, NULL);
 
        return g_hash_table_lookup (central_store->priv->hash_table, action_name);
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
@@ -17,36 +17,36 @@
 /**
  * SECTION:action-info-central-store
- * @Short_description: Aggregation of all TeplActionInfoStore's
- * @Title: TeplActionInfoCentralStore
- * @See_also: #TeplActionInfoStore
+ * @Short_description: Aggregation of all AmtkActionInfoStore's
+ * @Title: AmtkActionInfoCentralStore
+ * @See_also: #AmtkActionInfoStore
  *
@@ -17,36 +17,36 @@
  *
- * #TeplActionInfoCentralStore is a singleton class containing the aggregation
- * of all #TeplActionInfoStore's. Each time a #TeplActionInfo is added to a
- * #TeplActionInfoStore, it is also added to the #TeplActionInfoCentralStore.
+ * #AmtkActionInfoCentralStore is a singleton class containing the aggregation
+ * of all #AmtkActionInfoStore's. Each time a #AmtkActionInfo is added to a
+ * #AmtkActionInfoStore, it is also added to the #AmtkActionInfoCentralStore.
  */
 
@@ -17,36 +17,36 @@
 /* API design:
  *
- * Why both TeplActionInfoStore and TeplActionInfoCentralStore are needed?
+ * Why both AmtkActionInfoStore and AmtkActionInfoCentralStore are needed?
  *
@@ -17,36 +17,36 @@
  *
- * Advantages of TeplActionInfoStore:
- * - tepl_action_info_store_new() takes an optional GtkApplication parameter. It
+ * Advantages of AmtkActionInfoStore:
+ * - amtk_action_info_store_new() takes an optional GtkApplication parameter. It
  *   doesn't rely on g_application_get_default() (calling
  *   g_application_get_default() in a library is not really a good practice I
@@ -17,36 +17,36 @@
  *
- * Advantages of TeplActionInfoCentralStore:
+ * Advantages of AmtkActionInfoCentralStore:
  * - The central store checks if there are no duplicated action names
  *   (globally).
@@ -17,36 +17,36 @@
  *   (globally).
  * - [For the menu bar, easy to retrieve the tooltip to show it in the
- *   statusbar.] No longer relevant with tepl_menu_item_get_long_description().
+ *   statusbar.] No longer relevant with amtk_menu_item_get_long_description().
  *
  * If there was only one of the two classes, hacks would be needed to achieve
@@ -54,79 +54,79 @@
 {
        /* Key: owned gchar*: action name.
-        * Value: owned TeplActionInfo.
+        * Value: owned AmtkActionInfo.
         */
        GHashTable *hash_table;
@@ -54,79 +54,79 @@
  *
- * Returns: (transfer none): the #TeplActionInfoCentralStore singleton instance.
+ * Returns: (transfer none): the #AmtkActionInfoCentralStore singleton instance.
  * Since: 2.0
  */
@@ -134,22 +134,22 @@ _tepl_action_info_central_store_add (TeplActionInfoCentralStore *central_store,
  * @action_name: an action name.
  *
- * Returns: (transfer none): the found #TeplActionInfo, or %NULL.
+ * Returns: (transfer none): the found #AmtkActionInfo, or %NULL.
  * Since: 2.0
  */
diff --git a/amtk/tepl-action-info.h b/amtk/amtk-action-info.h
similarity index 51%
rename from amtk/tepl-action-info.h
rename to amtk/amtk-action-info.h
index 6f46d63..7127463 100644
--- a/amtk/tepl-action-info.h
+++ b/amtk/amtk-action-info.h
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,22 +17,22 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEPL_ACTION_INFO_H
-#define TEPL_ACTION_INFO_H
+#ifndef AMTK_ACTION_INFO_H
+#define AMTK_ACTION_INFO_H
 
 #if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
 #error "Only <tepl/tepl.h> can be included directly."
 #endif
 
 #include <glib-object.h>
-#include <tepl/tepl-types.h>
+#include <amtk/amtk-types.h>
 
 G_BEGIN_DECLS
 
-#define TEPL_TYPE_ACTION_INFO (tepl_action_info_get_type ())
+#define AMTK_TYPE_ACTION_INFO (amtk_action_info_get_type ())
 
 /**
- * TeplActionInfoEntry:
+ * AmtkActionInfoEntry:
  * @action_name: the action name.
  * @icon_name: the icon name, or %NULL.
  * @label: the label (i.e. a short description), or %NULL.
@@ -41,7 +41,7 @@ G_BEGIN_DECLS
  * @tooltip: the tooltip (i.e. a long description), or %NULL.
  *
  * This struct defines a set of information for a single action. It is for use
- * with tepl_action_info_store_add_entries().
+ * with amtk_action_info_store_add_entries().
  *
  * Like #GActionEntry, it is permissible to use an incomplete initialiser in
  * order to leave some of the later values as %NULL. Additional optional fields
@@ -49,7 +49,7 @@ G_BEGIN_DECLS
  *
  * Since: 2.0
  */
-struct _TeplActionInfoEntry
+struct _AmtkActionInfoEntry
 {
        const gchar *action_name;
        const gchar *icon_name;
@@ -61,50 +61,50 @@ struct _TeplActionInfoEntry
        gpointer padding[3];
 };
 
-GType                  tepl_action_info_get_type               (void) G_GNUC_CONST;
+GType                  amtk_action_info_get_type               (void) G_GNUC_CONST;
 
-TeplActionInfo *       tepl_action_info_new                    (void);
+AmtkActionInfo *       amtk_action_info_new                    (void);
 
-TeplActionInfo *       tepl_action_info_new_from_entry         (const TeplActionInfoEntry *info_entry,
+AmtkActionInfo *       amtk_action_info_new_from_entry         (const AmtkActionInfoEntry *info_entry,
                                                                 const gchar               
*translation_domain);
 
-TeplActionInfo *       tepl_action_info_ref                    (TeplActionInfo *info);
+AmtkActionInfo *       amtk_action_info_ref                    (AmtkActionInfo *info);
 
-void                   tepl_action_info_unref                  (TeplActionInfo *info);
+void                   amtk_action_info_unref                  (AmtkActionInfo *info);
 
-TeplActionInfo *       tepl_action_info_copy                   (const TeplActionInfo *info);
+AmtkActionInfo *       amtk_action_info_copy                   (const AmtkActionInfo *info);
 
-const gchar *          tepl_action_info_get_action_name        (const TeplActionInfo *info);
+const gchar *          amtk_action_info_get_action_name        (const AmtkActionInfo *info);
 
-void                   tepl_action_info_set_action_name        (TeplActionInfo *info,
+void                   amtk_action_info_set_action_name        (AmtkActionInfo *info,
                                                                 const gchar    *action_name);
 
-const gchar *          tepl_action_info_get_icon_name          (const TeplActionInfo *info);
+const gchar *          amtk_action_info_get_icon_name          (const AmtkActionInfo *info);
 
-void                   tepl_action_info_set_icon_name          (TeplActionInfo *info,
+void                   amtk_action_info_set_icon_name          (AmtkActionInfo *info,
                                                                 const gchar    *icon_name);
 
-const gchar *          tepl_action_info_get_label              (const TeplActionInfo *info);
+const gchar *          amtk_action_info_get_label              (const AmtkActionInfo *info);
 
-void                   tepl_action_info_set_label              (TeplActionInfo *info,
+void                   amtk_action_info_set_label              (AmtkActionInfo *info,
                                                                 const gchar    *label);
 
-const gchar *          tepl_action_info_get_tooltip            (const TeplActionInfo *info);
+const gchar *          amtk_action_info_get_tooltip            (const AmtkActionInfo *info);
 
-void                   tepl_action_info_set_tooltip            (TeplActionInfo *info,
+void                   amtk_action_info_set_tooltip            (AmtkActionInfo *info,
                                                                 const gchar    *tooltip);
 
-const gchar * const *  tepl_action_info_get_accels             (const TeplActionInfo *info);
+const gchar * const *  amtk_action_info_get_accels             (const AmtkActionInfo *info);
 
-void                   tepl_action_info_set_accels             (TeplActionInfo      *info,
+void                   amtk_action_info_set_accels             (AmtkActionInfo      *info,
                                                                 const gchar * const *accels);
 
 G_GNUC_INTERNAL
-gboolean               _tepl_action_info_get_used              (const TeplActionInfo *info);
+gboolean               _amtk_action_info_get_used              (const AmtkActionInfo *info);
 
 G_GNUC_INTERNAL
-void                   _tepl_action_info_set_used              (TeplActionInfo *info);
+void                   _amtk_action_info_set_used              (AmtkActionInfo *info);
 
 G_END_DECLS
 
-#endif  /* TEPL_ACTION_INFO_H */
+#endif  /* AMTK_ACTION_INFO_H */
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
@@ -17,22 +17,22 @@
 
-#if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
-#error "Only <tepl/tepl.h> can be included directly."
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
 #endif
 
diff --git a/amtk/tepl-action-map.c b/amtk/amtk-action-map.c
similarity index 87%
rename from amtk/tepl-action-map.c
rename to amtk/amtk-action-map.c
index 7ffc046..fee4a3b 100644
--- a/amtk/tepl-action-map.c
+++ b/amtk/amtk-action-map.c
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,12 +17,12 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "tepl-action-map.h"
+#include "amtk-action-map.h"
 
 /**
  * SECTION:action-map
  * @Short_description: GActionMap wrapper functions
- * @Title: TeplActionMap
+ * @Title: AmtkActionMap
  *
  * #GActionMap wrapper functions.
  */
@@ -40,7 +40,7 @@ check_dups_in_array (const GActionEntry *entries,
 
                if (g_strcmp0 (action_name, entry->name) == 0)
                {
-                       g_warning ("tepl_action_map_add_action_entries_check_dups(): "
+                       g_warning ("amtk_action_map_add_action_entries_check_dups(): "
                                   "the GActionEntry array contains duplicated entries for the action name 
'%s'. "
                                   "The first one will be dropped from the GActionMap.",
                                   action_name);
@@ -50,7 +50,7 @@ check_dups_in_array (const GActionEntry *entries,
 }
 
 /**
- * tepl_action_map_add_action_entries_check_dups:
+ * amtk_action_map_add_action_entries_check_dups:
  * @action_map: a #GActionMap.
  * @entries: (array length=n_entries) (element-type GActionEntry): a pointer to
  *           the first item in an array of #GActionEntry structs.
@@ -72,7 +72,7 @@ check_dups_in_array (const GActionEntry *entries,
  * Since: 2.0
  */
 void
-tepl_action_map_add_action_entries_check_dups (GActionMap         *action_map,
+amtk_action_map_add_action_entries_check_dups (GActionMap         *action_map,
                                               const GActionEntry *entries,
                                               gint                n_entries,
                                               gpointer            user_data)
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
diff --git a/amtk/tepl-action-map.h b/amtk/amtk-action-map.h
similarity index 64%
rename from amtk/tepl-action-map.h
rename to amtk/amtk-action-map.h
index 6252ca1..44fa2ae 100644
--- a/amtk/tepl-action-map.h
+++ b/amtk/amtk-action-map.h
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,22 +17,22 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEPL_ACTION_MAP_H
-#define TEPL_ACTION_MAP_H
+#ifndef AMTK_ACTION_MAP_H
+#define AMTK_ACTION_MAP_H
 
 #if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
 #error "Only <tepl/tepl.h> can be included directly."
 #endif
 
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
 
-void   tepl_action_map_add_action_entries_check_dups   (GActionMap         *action_map,
+void   amtk_action_map_add_action_entries_check_dups   (GActionMap         *action_map,
                                                         const GActionEntry *entries,
                                                         gint                n_entries,
                                                         gpointer            user_data);
 
 G_END_DECLS
 
-#endif /* TEPL_ACTION_MAP_H */
+#endif /* AMTK_ACTION_MAP_H */
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
@@ -17,22 +17,22 @@
 
-#if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
-#error "Only <tepl/tepl.h> can be included directly."
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
 #endif
 
diff --git a/amtk/tepl-menu-item.c b/amtk/amtk-menu-item.c
similarity index 86%
rename from amtk/tepl-menu-item.c
rename to amtk/amtk-menu-item.c
index d095ceb..26a6bb8 100644
--- a/amtk/tepl-menu-item.c
+++ b/amtk/amtk-menu-item.c
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,28 +17,28 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "tepl-menu-item.h"
+#include "amtk-menu-item.h"
 
 /**
  * SECTION:menu-item
  * @Short_description: GtkMenuItem functions
- * @Title: TeplMenuItem
+ * @Title: AmtkMenuItem
  *
  * #GtkMenuItem functions.
  */
 
-#define LONG_DESCRIPTION_KEY "tepl-menu-item-long-description-key"
+#define LONG_DESCRIPTION_KEY "amtk-menu-item-long-description-key"
 
 /**
- * tepl_menu_item_get_long_description:
+ * amtk_menu_item_get_long_description:
  * @menu_item: a #GtkMenuItem.
  *
  * Returns: (nullable): the long description of @menu_item, previously set with
- *   tepl_menu_item_set_long_description().
+ *   amtk_menu_item_set_long_description().
  * Since: 2.0
  */
 const gchar *
-tepl_menu_item_get_long_description (GtkMenuItem *menu_item)
+amtk_menu_item_get_long_description (GtkMenuItem *menu_item)
 {
        g_return_val_if_fail (GTK_IS_MENU_ITEM (menu_item), NULL);
 
@@ -46,7 +46,7 @@ tepl_menu_item_get_long_description (GtkMenuItem *menu_item)
 }
 
 /**
- * tepl_menu_item_set_long_description:
+ * amtk_menu_item_set_long_description:
  * @menu_item: a #GtkMenuItem.
  * @long_description: (nullable): the long description, or %NULL to unset it.
  *
@@ -56,7 +56,7 @@ tepl_menu_item_get_long_description (GtkMenuItem *menu_item)
  * Since: 2.0
  */
 void
-tepl_menu_item_set_long_description (GtkMenuItem *menu_item,
+amtk_menu_item_set_long_description (GtkMenuItem *menu_item,
                                     const gchar *long_description)
 {
        g_return_if_fail (GTK_IS_MENU_ITEM (menu_item));
@@ -68,7 +68,7 @@ tepl_menu_item_set_long_description (GtkMenuItem *menu_item,
 }
 
 /**
- * tepl_menu_item_set_icon_name:
+ * amtk_menu_item_set_icon_name:
  * @item: a #GtkMenuItem.
  * @icon_name: an icon name.
  *
@@ -92,7 +92,7 @@ tepl_menu_item_set_long_description (GtkMenuItem *menu_item,
  * Copyright 2011, 2013 Canonical Limited
  */
 void
-tepl_menu_item_set_icon_name (GtkMenuItem *item,
+amtk_menu_item_set_icon_name (GtkMenuItem *item,
                              const gchar *icon_name)
 {
        GtkWidget *child;
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
diff --git a/amtk/tepl-menu-item.h b/amtk/amtk-menu-item.h
similarity index 57%
rename from amtk/tepl-menu-item.h
rename to amtk/amtk-menu-item.h
index ebb371a..dffc6d9 100644
--- a/amtk/tepl-menu-item.h
+++ b/amtk/amtk-menu-item.h
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,25 +17,25 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEPL_MENU_ITEM_H
-#define TEPL_MENU_ITEM_H
+#ifndef AMTK_MENU_ITEM_H
+#define AMTK_MENU_ITEM_H
 
 #if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
 #error "Only <tepl/tepl.h> can be included directly."
 #endif
 
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-const gchar *  tepl_menu_item_get_long_description     (GtkMenuItem *menu_item);
+const gchar *  amtk_menu_item_get_long_description     (GtkMenuItem *menu_item);
 
-void           tepl_menu_item_set_long_description     (GtkMenuItem *menu_item,
+void           amtk_menu_item_set_long_description     (GtkMenuItem *menu_item,
                                                         const gchar *long_description);
 
-void           tepl_menu_item_set_icon_name            (GtkMenuItem *item,
+void           amtk_menu_item_set_icon_name            (GtkMenuItem *item,
                                                         const gchar *icon_name);
 
 G_END_DECLS
 
-#endif  /* TEPL_MENU_ITEM_H */
+#endif  /* AMTK_MENU_ITEM_H */
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
@@ -17,25 +17,25 @@
 
-#if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
-#error "Only <tepl/tepl.h> can be included directly."
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
 #endif
 
diff --git a/amtk/tepl-types.h b/amtk/amtk-types.h
similarity index 50%
rename from amtk/tepl-types.h
rename to amtk/amtk-types.h
index e9ce253..7c8f961 100644
--- a/amtk/tepl-types.h
+++ b/amtk/amtk-types.h
@@ -1,14 +1,14 @@
 /*
  * This file is part of Tepl, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
  * Tepl is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
  * option) any later version.
  *
  * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  * License for more details.
@@ -17,23 +17,23 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEPL_TYPES_H
-#define TEPL_TYPES_H
+#ifndef AMTK_TYPES_H
+#define AMTK_TYPES_H
 
 #if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
 #error "Only <tepl/tepl.h> can be included directly."
 #endif
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-typedef struct _TeplActionInfo                 TeplActionInfo;
-typedef struct _TeplActionInfoEntry            TeplActionInfoEntry;
-typedef struct _TeplActionInfoStore            TeplActionInfoStore;
-typedef struct _TeplActionInfoCentralStore     TeplActionInfoCentralStore;
-typedef struct _TeplMenuShell                  TeplMenuShell;
+typedef struct _AmtkActionInfo                 AmtkActionInfo;
+typedef struct _AmtkActionInfoEntry            AmtkActionInfoEntry;
+typedef struct _AmtkActionInfoStore            AmtkActionInfoStore;
+typedef struct _AmtkActionInfoCentralStore     AmtkActionInfoCentralStore;
+typedef struct _AmtkMenuShell                  AmtkMenuShell;
 
 G_END_DECLS
 
-#endif /* TEPL_TYPES_H */
+#endif /* AMTK_TYPES_H */
@@ -1,14 +1,14 @@
 /*
- * This file is part of Tepl, a text editor library.
+ * This file is part of Amtk, a text editor library.
  *
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
@@ -1,14 +1,14 @@
  * Copyright 2017 - Sébastien Wilmet <swilmet gnome org>
  *
- * Tepl is free software; you can redistribute it and/or modify it under
+ * Amtk is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
  * Free Software Foundation; either version 2.1 of the License, or (at your
@@ -1,14 +1,14 @@
  * option) any later version.
  *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Amtk is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
@@ -17,23 +17,23 @@
 
-#if !defined (TEPL_H_INSIDE) && !defined (TEPL_COMPILATION)
-#error "Only <tepl/tepl.h> can be included directly."
+#if !defined (AMTK_H_INSIDE) && !defined (AMTK_COMPILATION)
+#error "Only <amtk/amtk.h> can be included directly."
 #endif
 